Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(643)

Unified Diff: net/quic/quic_session.h

Issue 18033005: Cleanup of OpenSSL/NSS implementation of ProofVerfifier release. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Implemented wtc's comments Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_crypto_client_stream.cc ('k') | net/quic/quic_session.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_session.h
diff --git a/net/quic/quic_session.h b/net/quic/quic_session.h
index bd3f60458a3c9b4d8f18d641117cd5b255ca1d43..f70ebb2639ac9f79de1e065938f8e1a25a3289da 100644
--- a/net/quic/quic_session.h
+++ b/net/quic/quic_session.h
@@ -107,11 +107,11 @@ class NET_EXPORT_PRIVATE QuicSession : public QuicConnectionVisitorInterface {
virtual ProofVerifier* proof_verifier() const;
// SetProofVerifier takes ownership of a |ProofVerifier| that clients are
// free to use in order to verify certificate chains from servers. If a
// ProofVerifier is set then the client will request a certificate chain from
// the server.
- virtual void SetProofVerifier(ProofVerifier* verifier);
+ virtual void set_proof_verifier(ProofVerifier* verifier);
// Returns mutable config for this session. Returned config is owned
// by QuicSession.
« no previous file with comments | « net/quic/quic_crypto_client_stream.cc ('k') | net/quic/quic_session.cc » ('j') | no next file with comments »
@@ -107,11 +107,11 @@ class NET_EXPORT_PRIVATE QuicSession : public QuicConnectionVisitorInterface {
virtual ProofVerifier* proof_verifier() const;
- // SetProofVerifier takes ownership of a |ProofVerifier| that clients are
+ // set_proof_verifier takes ownership of a |ProofVerifier| that clients are
// free to use in order to verify certificate chains from servers. If a
// ProofVerifier is set then the client will request a certificate chain from

Powered by Google App Engine
This is Rietveld 408576698